function axis_limits = get_limits(markers)
% axis_limits = get_limits(markers)
%
% Given a matrix of markers (# frames)*(# points)*3, compute the
% proper arguments to the "axis()" function, so that all the markers
% will fit in the figure.

% Author: David Ross, Nov. 2006.
% $Id: get_limits.m,v 1.3 2007-03-20 19:02:43 dross Exp $

error(nargchk(1,1,nargin));

if ~any(size(markers,3) == [2 3])
    error('this function requires size(markers,3)== 2 or 3');
end

% find the limits of the axes
% assume markers is F*(#markers)*3
mm = permute(markers,[3 2 1]);
ax_min = min(mm(:,:),[],2);
ax_max = max(mm(:,:),[],2);

if size(markers,3) == 3
    axis_limits = [ax_min(1) ax_max(1) ...
                   ax_min(2) ax_max(2) ...
                   ax_min(3) ax_max(3)];
else
    axis_limits = [ax_min(1) ax_max(1) ...
                   ax_min(2) ax_max(2)];    
end
